# -*- coding: utf-8 -*-
from setuphelpers import *
import json

# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls

bin_contains = "OpenJDK17"
openjdk_version = "17"
bin_type = "jre"


def update_package():
    # Declaring local variables
    arch = control.architecture
    result = False
    proxies = get_proxies()

    if not proxies:
        proxies = get_proxies_from_wapt_console()
    app_name = control.name
    # api : https://api.adoptium.net/q/swagger-ui/#/Assets/searchReleases
    url_api_64 = (
        "https://api.adoptium.net/v3/assets/feature_releases/%s/ga?architecture=x64&heap_size=normal&image_type=%s&jvm_impl=hotspot&os=windows&page=0&page_size=10&project=jdk&sort_method=DEFAULT&sort_order=DESC&vendor=eclipse"
        % (openjdk_version, bin_type)
    )
    url_api_32 = (
        "https://api.adoptium.net/v3/assets/feature_releases/%s/ga?architecture=x32&heap_size=normal&image_type=%s&jvm_impl=hotspot&os=windows&page=0&page_size=10&project=jdk&sort_method=DEFAULT&sort_order=DESC&vendor=eclipse"
        % (openjdk_version, bin_type)
    )

    # Getting latest version information from official sources
    print("API used is: %s" % url_api_64)
    json_load = json.loads(wgets(url_api_64, proxies=proxies))

    # getting  latest 64 bit version
    found = False

    for releases in json_load:
        if found:
            break
        for binary in releases["binaries"]:
            if (
                bin_contains.lower() in binary["installer"]["link"].lower()
                and binary["image_type"].lower() == bin_type.lower()
                and binary["architecture"].lower() == "x64"
                and binary["installer"]["link"].endswith(".msi")
            ):
                version_64 = binary["scm_ref"].split("jdk-")[1].split("_")[0].replace("+", ".")
                url_dl_64 = binary["installer"]["link"]
                latest_bin_64 = url_dl_64.rsplit("/", 1)[1]
                found = True
                break
    # getting  latest 32 bit version
    found = False
    print("API used is: %s" % url_api_32)
    json_load = json.loads(wgets(url_api_32, proxies=proxies))

    for releases in json_load:
        if found:
            break
        for binary in releases["binaries"]:
            if (
                bin_contains.lower() in binary["installer"]["link"].lower()
                and binary["image_type"].lower() == bin_type.lower()
                and binary["architecture"].lower() == "x32"
                and binary["installer"]["link"].endswith(".msi")
            ):
                version_86 = binary["scm_ref"].split("jdk-")[1].split("_")[0].replace("+", ".")
                url_dl_86 = binary["installer"]["link"]
                latest_bin_86 = url_dl_86.rsplit("/", 1)[1]
                found = True
                break
    if version_64:
        version = version_64
    elif version_86:
        version = version_86
    else:
        print("ERROR: Couldn't fin the software version")

    # Deleting outdated binaries
    remove_outdated_binaries(version)

    print("Latest %s version is: %s" % (app_name, version))
    print("Download URL  for x86 is: %s" % url_dl_86)
    print("Download URL  for x64 is: %s" % url_dl_64)
    # Downloading latest 64 bit binaries
    if not isfile(latest_bin_64):
        for bin_64 in glob.glob("*%s*64*.msi" % bin_contains):
            remove_file(bin_64)
        if arch == "all" or arch == "x64":
            print("Downloading: %s" % latest_bin_64)
            wget(url_dl_64, latest_bin_64, proxies=proxies)

    # Downloading latest 32 bit binaries
    if not isfile(latest_bin_86):
        for bin_86 in glob.glob("*%s*86*.msi" % bin_contains):
            remove_file(bin_86)
        if arch == "all" or arch == "x86":
            print("Downloading: %s" % latest_bin_86)
            wget(url_dl_86, latest_bin_86, proxies=proxies)

    if arch == "x86":
        latest_bin = latest_bin_86
    else:
        latest_bin = latest_bin_64
    # Checking version from file
    version_from_file = get_version_from_binary(latest_bin)

    if Version(version_from_file) != Version(version_64) and version_from_file != "":
        print("Changing version to the version number of the binary")
        for f in glob.glob(bin_contains + "*.msi"):
            new_name = f.split("windows_hotspot_")[0] + version_from_file + ".msi"
            os.rename(f, new_name)
        version = version_from_file
    else:
        print("Binary file version corresponds to online version")

    # Changing version of the package
    if Version(version) > Version(control.get_software_version()):
        print("Software version updated (from: %s to: %s)" % (control.get_software_version(), Version(version)))
        result = True
    else:
        print("Software version up-to-date (%s)" % Version(version))
    control.version = "%s-%s" % (Version(version), control.version.split("-", 1)[-1])
    control.save_control_to_wapt()

    # Validating update-package-sources
    return result
